<?php

namespace Litepie\Campaign\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Campaign\Models\CampaignTask;

class CampaignTaskPolicy
{

    /**
     * Determine if the given user can view the campaign_task.
     *
     * @param UserPolicy $user
     * @param CampaignTask $campaign_task
     *
     * @return bool
     */
    public function view(UserPolicy $user, CampaignTask $campaign_task)
    {
        if ($user->canDo('campaign.campaign_task.view') && $user->isAdmin()) {
            return true;
        }

        return $campaign_task->user_id == user_id() && $campaign_task->user_type == user_type();
    }

    /**
     * Determine if the given user can create a campaign_task.
     *
     * @param UserPolicy $user
     * @param CampaignTask $campaign_task
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('campaign.campaign_task.create');
    }

    /**
     * Determine if the given user can update the given campaign_task.
     *
     * @param UserPolicy $user
     * @param CampaignTask $campaign_task
     *
     * @return bool
     */
    public function update(UserPolicy $user, CampaignTask $campaign_task)
    {
        if ($user->canDo('campaign.campaign_task.edit') && $user->isAdmin()) {
            return true;
        }

        return $campaign_task->user_id == user_id() && $campaign_task->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given campaign_task.
     *
     * @param UserPolicy $user
     * @param CampaignTask $campaign_task
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CampaignTask $campaign_task)
    {
        return $campaign_task->user_id == user_id() && $campaign_task->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given campaign_task.
     *
     * @param UserPolicy $user
     * @param CampaignTask $campaign_task
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CampaignTask $campaign_task)
    {
        if ($user->canDo('campaign.campaign_task.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given campaign_task.
     *
     * @param UserPolicy $user
     * @param CampaignTask $campaign_task
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CampaignTask $campaign_task)
    {
        if ($user->canDo('campaign.campaign_task.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
