<?php

namespace Litepie\Campaign\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Campaign\Models\CampignCooperation;

class CampignCooperationPolicy
{

    /**
     * Determine if the given user can view the campign_cooperation.
     *
     * @param UserPolicy $user
     * @param CampignCooperation $campign_cooperation
     *
     * @return bool
     */
    public function view(UserPolicy $user, CampignCooperation $campign_cooperation)
    {
        if ($user->canDo('campaign.campign_cooperation.view') && $user->isAdmin()) {
            return true;
        }

        return $campign_cooperation->user_id == user_id() && $campign_cooperation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a campign_cooperation.
     *
     * @param UserPolicy $user
     * @param CampignCooperation $campign_cooperation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('campaign.campign_cooperation.create');
    }

    /**
     * Determine if the given user can update the given campign_cooperation.
     *
     * @param UserPolicy $user
     * @param CampignCooperation $campign_cooperation
     *
     * @return bool
     */
    public function update(UserPolicy $user, CampignCooperation $campign_cooperation)
    {
        if ($user->canDo('campaign.campign_cooperation.edit') && $user->isAdmin()) {
            return true;
        }

        return $campign_cooperation->user_id == user_id() && $campign_cooperation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given campign_cooperation.
     *
     * @param UserPolicy $user
     * @param CampignCooperation $campign_cooperation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CampignCooperation $campign_cooperation)
    {
        return $campign_cooperation->user_id == user_id() && $campign_cooperation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given campign_cooperation.
     *
     * @param UserPolicy $user
     * @param CampignCooperation $campign_cooperation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CampignCooperation $campign_cooperation)
    {
        if ($user->canDo('campaign.campign_cooperation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given campign_cooperation.
     *
     * @param UserPolicy $user
     * @param CampignCooperation $campign_cooperation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CampignCooperation $campign_cooperation)
    {
        if ($user->canDo('campaign.campign_cooperation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
