<?php

namespace Litepie\Campaign\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litepie\Campaign\Models\Campaign;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litepie\Campaign\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/campaign/campaign_task/*')) {
            Route::bind('campaign_task', function ($campaign_task) {
                $campaign_taskrepo = $this->app->make('Litepie\Campaign\Interfaces\CampaignTaskRepositoryInterface');
                return $campaign_taskrepo->findorNew($campaign_task);
            });
        }

        if (Request::is('*/campaign/campaign/*')) {
            Route::bind('campaign', function ($campaign) {
                $campaignrepo = $this->app->make('Litepie\Campaign\Interfaces\CampaignRepositoryInterface');
                return $campaignrepo->findorNew($campaign);
            });
        }

        if (Request::is('*/campaign/campaign_variant/*')) {
            Route::bind('campaign_variant', function ($campaign_variant) {
                $campaign_variantrepo = $this->app->make('Litepie\Campaign\Interfaces\CampaignVariantRepositoryInterface');
                return $campaign_variantrepo->findorNew($campaign_variant);
            });
        }

        if (Request::is('*/campaign/campign_cooperation/*')) {
            Route::bind('campign_cooperation', function ($campign_cooperation) {
                $campign_cooperationrepo = $this->app->make('Litepie\Campaign\Interfaces\CampignCooperationRepositoryInterface');
                return $campign_cooperationrepo->findorNew($campign_cooperation);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
